==> sbi-0.14.1.tar.gz: sbi-0.14.1/docs/docs/reference.md <==
# API Reference

## Inference

::: sbi.inference.base.infer
    rendering:
      show_root_heading: true

::: sbi.user_input.user_input_checks.prepare_for_sbi
    rendering:
      show_root_heading: true
      
::: sbi.inference.base.simulate_for_sbi
    rendering:
      show_root_heading: true

::: sbi.inference.snpe.snpe_c.SNPE_C
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.snle.snle_a.SNLE_A
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.snre.snre_a.SNRE_A
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.snre.snre_b.SNRE_B
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.abc.mcabc.MCABC
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.abc.smcabc.SMCABC
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

## Posteriors

::: sbi.inference.posteriors.direct_posterior.DirectPosterior
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true
      
::: sbi.inference.posteriors.likelihood_based_posterior.LikelihoodBasedPosterior
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true
      
::: sbi.inference.posteriors.ratio_based_posterior.RatioBasedPosterior
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

## Models

::: sbi.utils.get_nn_models.posterior_nn
    rendering:
      show_root_heading: true
      show_object_full_path: true

::: sbi.utils.get_nn_models.likelihood_nn
    rendering:
      show_root_heading: true
      show_object_full_path: true

::: sbi.utils.get_nn_models.classifier_nn
    rendering:
      show_root_heading: true
      show_object_full_path: true

## Utils

::: sbi.utils.plot.pairplot
    rendering:
      show_root_heading: true
      show_object_full_path: true
      
::: sbi.utils.plot.conditional_pairplot
    rendering:
      show_root_heading: true
      show_object_full_path: true
      
::: sbi.utils.conditional_density.conditional_corrcoeff
    rendering:
      show_root_heading: true
      show_object_full_path: true

==> sbi-0.15.0.tar.gz: sbi-0.15.0/docs/docs/reference.md <==
# API Reference

## Inference

::: sbi.inference.base.infer
    rendering:
      show_root_heading: true

::: sbi.utils.user_input_checks.prepare_for_sbi
    rendering:
      show_root_heading: true
      
::: sbi.inference.base.simulate_for_sbi
    rendering:
      show_root_heading: true

::: sbi.inference.snpe.snpe_c.SNPE_C
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.snle.snle_a.SNLE_A
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.snre.snre_a.SNRE_A
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.snre.snre_b.SNRE_B
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.abc.mcabc.MCABC
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

::: sbi.inference.abc.smcabc.SMCABC
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

## Posteriors

::: sbi.inference.posteriors.direct_posterior.DirectPosterior
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true
      
::: sbi.inference.posteriors.likelihood_based_posterior.LikelihoodBasedPosterior
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true
      
::: sbi.inference.posteriors.ratio_based_posterior.RatioBasedPosterior
    rendering:
      show_root_heading: true
    selection:
      filters: [ "!^_", "^__", "!^__class__" ]
      inherited_members: true

## Models

::: sbi.utils.get_nn_models.posterior_nn
    rendering:
      show_root_heading: true
      show_object_full_path: true

::: sbi.utils.get_nn_models.likelihood_nn
    rendering:
      show_root_heading: true
      show_object_full_path: true

::: sbi.utils.get_nn_models.classifier_nn
    rendering:
      show_root_heading: true
      show_object_full_path: true

## Analysis

::: sbi.analysis.plot.pairplot
    rendering:
      show_root_heading: true
      show_object_full_path: true
      
::: sbi.analysis.plot.conditional_pairplot
    rendering:
      show_root_heading: true
      show_object_full_path: true
      
::: sbi.analysis.conditional_density.conditional_corrcoeff
    rendering:
      show_root_heading: true
      show_object_full_path: true
